[][src]Module oasis_std::collections::map

Structs

Map

Map is a data structure with a HashMap-like API but based on a Vec. It's primarily useful when you care about constant factors or prefer determinism to speed. Please refer to the docs for HashMap for details and examples of the Map API.

OccupiedEntry
VacantEntry

Enums

Entry