[−][src]Struct oasis_std::exe::Context
The context of the current RPC.
Methods
impl Context[src]
pub fn delegated() -> Self[src]
pub fn with_gas(self, gas: u64) -> Self[src]
Sets the amount of computation resources available to the callee. Has no effect when called inside of a service.
pub fn sender(&self) -> Address[src]
Returns the Address of the sender of the current RPC.
pub fn address(&self) -> Address[src]
Returns the Address of the currently executing service.
Panics if not called from within a service RPC.
pub fn value(&self) -> u64[src]
Returns the value with which this Context was created.
impl Context[src]
pub fn with_sender(self, sender: Address) -> Self[src]
Sets the sender of the RPC receiving this Context as an argument.
Has no effect when called inside of a service.
pub fn with_value(self, value: u64) -> Self[src]
Amends a Context with the value that should be transferred to the callee.