[][src]Enum oasis_std::exe::RpcError

pub enum RpcError<T> {
    NoAccount,
    InsufficientFunds,
    InsufficientGas,
    InvalidInput,
    InvalidOutput(Vec<u8>),
    Exec(T),
}

Variants

NoAccount

There was no service at the requested address.

InsufficientFunds

The caller does not have enough balance to cover the sent value.

InsufficientGas

The caller did not provide enough gas to complete the transaction.

InvalidInputInvalidOutput(Vec<u8>)Exec(T)

The application returned an error.