[−][src]Enum oasis_std::exe::RpcError
Variants
NoAccountThere was no service at the requested address.
InsufficientFundsThe caller does not have enough balance to cover the sent value.
InsufficientGasThe caller did not provide enough gas to complete the transaction.
InvalidInputInvalidOutput(Vec<u8>)Exec(T)The application returned an error.